@@ -628,6 +628,7 @@ pub trait QueryBuilder: QuotedBuilder {
                     Function::Min => "MIN",
                     Function::Sum => "SUM",
                     Function::Avg => "AVG",
+                    Function::Coalesce => "COALESCE",
                     Function::Count => "COUNT",
                     Function::IfNull => self.if_null_function(),
                     Function::CharLength => self.char_length_function(),
@@ -852,9 +853,11 @@ pub trait QueryBuilder: QuotedBuilder {
         sql: &mut SqlWriter,
         collector: &mut dyn FnMut(Value),
     ) {
-        self.prepare_simple_expr(&order_expr.expr, sql, collector);
+        if !matches!(order_expr.order, Order::Field(_)) {
+            self.prepare_simple_expr(&order_expr.expr, sql, collector);
+        }
         write!(sql, " ").unwrap();
-        self.prepare_order(&order_expr.order, sql, collector);
+        self.prepare_order(order_expr, sql, collector);
     }
 
     /// Translate [`JoinOn`] into SQL statement.
@@ -871,13 +874,41 @@ pub trait QueryBuilder: QuotedBuilder {
     }
 
     /// Translate [`Order`] into SQL statement.
-    fn prepare_order(&self, order: &Order, sql: &mut SqlWriter, _collector: &mut dyn FnMut(Value)) {
-        match order {
+    fn prepare_order(
+        &self,
+        order_expr: &OrderExpr,
+        sql: &mut SqlWriter,
+        collector: &mut dyn FnMut(Value),
+    ) {
+        match &order_expr.order {
             Order::Asc => write!(sql, "ASC").unwrap(),
             Order::Desc => write!(sql, "DESC").unwrap(),
+            Order::Field(values) => self.prepare_field_order(order_expr, values, sql, collector),
         }
     }
 
+    /// Translate [`Order::Field`] into SQL statement
+    fn prepare_field_order(
+        &self,
+        order_expr: &OrderExpr,
+        values: &Values,
+        sql: &mut SqlWriter,
+        collector: &mut dyn FnMut(Value),
+    ) {
+        write!(sql, "CASE ").unwrap();
+        let mut i = 0;
+        for value in &values.0 {
+            write!(sql, " WHEN ").unwrap();
+            self.prepare_simple_expr(&order_expr.expr, sql, collector);
+            write!(sql, "=").unwrap();
+            let value = self.value_to_string(value);
+            write!(sql, "{}", value).unwrap();
+            write!(sql, " THEN {} ", i).unwrap();
+            i += 1;
+        }
+        write!(sql, "ELSE {} END", i).unwrap();
+    }
+
     /// Translate [`Value`] into SQL statement.
     fn prepare_value(&self, value: &Value, sql: &mut SqlWriter, collector: &mut dyn FnMut(Value)) {
         let (placeholder, numbered) = self.placeholder();
@@ -945,17 +976,25 @@ pub trait QueryBuilder: QuotedBuilder {
             #[cfg(feature = "with-json")]
             Value::Json(None) => write!(s, "NULL").unwrap(),
             #[cfg(feature = "with-chrono")]
-            Value::Date(None) => write!(s, "NULL").unwrap(),
+            Value::ChronoDate(None) => write!(s, "NULL").unwrap(),
             #[cfg(feature = "with-chrono")]
-            Value::Time(None) => write!(s, "NULL").unwrap(),
+            Value::ChronoTime(None) => write!(s, "NULL").unwrap(),
             #[cfg(feature = "with-chrono")]
-            Value::DateTime(None) => write!(s, "NULL").unwrap(),
+            Value::ChronoDateTime(None) => write!(s, "NULL").unwrap(),
             #[cfg(feature = "with-chrono")]
-            Value::DateTimeUtc(None) => write!(s, "NULL").unwrap(),
+            Value::ChronoDateTimeUtc(None) => write!(s, "NULL").unwrap(),
             #[cfg(feature = "with-chrono")]
-            Value::DateTimeLocal(None) => write!(s, "NULL").unwrap(),
+            Value::ChronoDateTimeLocal(None) => write!(s, "NULL").unwrap(),
             #[cfg(feature = "with-chrono")]
-            Value::DateTimeWithTimeZone(None) => write!(s, "NULL").unwrap(),
+            Value::ChronoDateTimeWithTimeZone(None) => write!(s, "NULL").unwrap(),
+            #[cfg(feature = "with-time")]
+            Value::TimeDate(None) => write!(s, "NULL").unwrap(),
+            #[cfg(feature = "with-time")]
+            Value::TimeTime(None) => write!(s, "NULL").unwrap(),
+            #[cfg(feature = "with-time")]
+            Value::TimeDateTime(None) => write!(s, "NULL").unwrap(),
+            #[cfg(feature = "with-time")]
+            Value::TimeDateTimeWithTimeZone(None) => write!(s, "NULL").unwrap(),
             #[cfg(feature = "with-rust_decimal")]
             Value::Decimal(None) => write!(s, "NULL").unwrap(),
             #[cfg(feature = "with-bigdecimal")]
@@ -985,25 +1024,41 @@ pub trait QueryBuilder: QuotedBuilder {
             #[cfg(feature = "with-json")]
             Value::Json(Some(v)) => self.write_string_quoted(&v.to_string(), &mut s),
             #[cfg(feature = "with-chrono")]
-            Value::Date(Some(v)) => write!(s, "\'{}\'", v.format("%Y-%m-%d").to_string()).unwrap(),
+            Value::ChronoDate(Some(v)) => {
+                write!(s, "\'{}\'", v.format("%Y-%m-%d").to_string()).unwrap()
+            }
             #[cfg(feature = "with-chrono")]
-            Value::Time(Some(v)) => write!(s, "\'{}\'", v.format("%H:%M:%S").to_string()).unwrap(),
+            Value::ChronoTime(Some(v)) => {
+                write!(s, "\'{}\'", v.format("%H:%M:%S").to_string()).unwrap()
+            }
             #[cfg(feature = "with-chrono")]
-            Value::DateTime(Some(v)) => {
+            Value::ChronoDateTime(Some(v)) => {
                 write!(s, "\'{}\'", v.format("%Y-%m-%d %H:%M:%S").to_string()).unwrap()
             }
             #[cfg(feature = "with-chrono")]
-            Value::DateTimeUtc(Some(v)) => {
+            Value::ChronoDateTimeUtc(Some(v)) => {
                 write!(s, "\'{}\'", v.format("%Y-%m-%d %H:%M:%S %:z").to_string()).unwrap()
             }
             #[cfg(feature = "with-chrono")]
-            Value::DateTimeLocal(Some(v)) => {
+            Value::ChronoDateTimeLocal(Some(v)) => {
                 write!(s, "\'{}\'", v.format("%Y-%m-%d %H:%M:%S %:z").to_string()).unwrap()
             }
             #[cfg(feature = "with-chrono")]
-            Value::DateTimeWithTimeZone(Some(v)) => {
+            Value::ChronoDateTimeWithTimeZone(Some(v)) => {
                 write!(s, "\'{}\'", v.format("%Y-%m-%d %H:%M:%S %:z").to_string()).unwrap()
             }
+            #[cfg(feature = "with-time")]
+            Value::TimeDate(Some(v)) => write!(s, "\'{}\'", v.format("%Y-%m-%d")).unwrap(),
+            #[cfg(feature = "with-time")]
+            Value::TimeTime(Some(v)) => write!(s, "\'{}\'", v.format("%H:%M:%S")).unwrap(),
+            #[cfg(feature = "with-time")]
+            Value::TimeDateTime(Some(v)) => {
+                write!(s, "\'{}\'", v.format("%Y-%m-%d %H:%M:%S")).unwrap()
+            }
+            #[cfg(feature = "with-time")]
+            Value::TimeDateTimeWithTimeZone(Some(v)) => {
+                write!(s, "\'{}\'", v.format("%Y-%m-%d %H:%M:%S %z")).unwrap()
+            }
             #[cfg(feature = "with-rust_decimal")]
             Value::Decimal(Some(v)) => write!(s, "{}", v).unwrap(),
             #[cfg(feature = "with-bigdecimal")]
