@@ -914,6 +914,63 @@ fn select_54() {
     );
 }
 
+#[test]
+fn select_55() {
+    assert_eq!(
+        Query::select()
+            .columns(vec![Glyph::Aspect,])
+            .from(Glyph::Table)
+            .and_where(Expr::expr(Expr::col(Glyph::Aspect).if_null(0)).gt(2))
+            .order_by(
+                Glyph::Id,
+                Order::Field(Values(vec![4.into(), 5.into(), 1.into(), 3.into(),]))
+            )
+            .order_by((Glyph::Table, Glyph::Aspect), Order::Asc)
+            .to_string(MysqlQueryBuilder),
+        [
+            r#"SELECT `aspect`"#,
+            r#"FROM `glyph`"#,
+            r#"WHERE IFNULL(`aspect`, 0) > 2"#,
+            r#"ORDER BY CASE"#,
+            r#"WHEN `id`=4 THEN 0"#,
+            r#"WHEN `id`=5 THEN 1"#,
+            r#"WHEN `id`=1 THEN 2"#,
+            r#"WHEN `id`=3 THEN 3"#,
+            r#"ELSE 4 END,"#,
+            r#"`glyph`.`aspect` ASC"#,
+        ]
+        .join(" ")
+    );
+}
+
+#[test]
+fn select_56() {
+    assert_eq!(
+        Query::select()
+            .columns(vec![Glyph::Aspect,])
+            .from(Glyph::Table)
+            .and_where(Expr::expr(Expr::col(Glyph::Aspect).if_null(0)).gt(2))
+            .order_by((Glyph::Table, Glyph::Aspect), Order::Asc)
+            .order_by(
+                Glyph::Id,
+                Order::Field(Values(vec![4.into(), 5.into(), 1.into(), 3.into(),]))
+            )
+            .to_string(MysqlQueryBuilder),
+        [
+            r#"SELECT `aspect`"#,
+            r#"FROM `glyph`"#,
+            r#"WHERE IFNULL(`aspect`, 0) > 2"#,
+            r#"ORDER BY `glyph`.`aspect` ASC,"#,
+            r#"CASE WHEN `id`=4 THEN 0"#,
+            r#"WHEN `id`=5 THEN 1"#,
+            r#"WHEN `id`=1 THEN 2"#,
+            r#"WHEN `id`=3 THEN 3"#,
+            r#"ELSE 4 END"#,
+        ]
+        .join(" ")
+    );
+}
+
 #[test]
 #[allow(clippy::approx_constant)]
 fn insert_2() {
@@ -969,6 +1026,22 @@ fn insert_4() {
     );
 }
 
+#[test]
+#[cfg(feature = "with-time")]
+fn insert_8() {
+    use time::{date, time};
+    assert_eq!(
+        Query::insert()
+            .into_table(Glyph::Table)
+            .columns(vec![Glyph::Image])
+            .values_panic(vec![date!(1970 - 01 - 01)
+                .with_time(time!(00:00:00))
+                .into()])
+            .to_string(MysqlQueryBuilder),
+        "INSERT INTO `glyph` (`image`) VALUES ('1970-01-01 00:00:00')"
+    );
+}
+
 #[test]
 #[cfg(feature = "with-uuid")]
 fn insert_5() {
